Index: /branches/rel10_ifa/psModules/src/astrom/pmFPAConstruct.c
===================================================================
--- /branches/rel10_ifa/psModules/src/astrom/pmFPAConstruct.c	(revision 6751)
+++ /branches/rel10_ifa/psModules/src/astrom/pmFPAConstruct.c	(revision 6752)
@@ -70,5 +70,5 @@
 // Get the name of a PHU chip or cell from the header
 static psString phuNameFromHeader(const char *name, // The name to lookup: "CELL.NAME" or "CHIP.NAME"
-                                  const psMetadata *format, // FORMAT within the camera format description
+                                  const psMetadata *format, // FILE within the camera format description
                                   const psMetadata *header // Primary header
                                  )
@@ -77,5 +77,5 @@
     psString keyword = psMetadataLookupStr(&mdok, format, name);
     if (!mdok || strlen(keyword) == 0) {
-        psError(PS_ERR_IO, false, "Unable to find %s in the FORMAT.\n", name);
+        psError(PS_ERR_IO, false, "Unable to find %s in the FILE.\n", name);
         return false;
     }
@@ -142,7 +142,7 @@
 
     bool mdok = true;                   // Status from metadata lookups
-    psMetadata *formatSpec = psMetadataLookupMD(&mdok, format, "FORMAT"); // The format specification
+    psMetadata *formatSpec = psMetadataLookupMD(&mdok, format, "FILE"); // The format specification
     if (!mdok || !formatSpec) {
-        psError(PS_ERR_IO, false, "Unable to find FORMAT in the camera format configuration.\n");
+        psError(PS_ERR_IO, false, "Unable to find FILE in the camera format configuration.\n");
         return NULL;
     }
